/* Toolbar Button */

#feedback-menu-button {
  -moz-box-orient: horizontal;
}

#feedback-menu-button .toolbarbutton-text {
  display: -moz-box;
  margin: 0;
  color: -moz-dialogtext;
  text-shadow: none;
}

#feedback-menu-button .toolbarbutton-icon {
  display: none;
}

#feedback-menu-button .toolbarbutton-menu-dropmarker {
  -moz-padding-start: 5px;
}


#pilot-notifications-button {
  margin-right: 10px;
}

/* Popup Bounding Box */
#pilot-notification-popup {
  -moz-appearance: none;
  -moz-window-shadow: none;
  background-color: transparent;
  margin-top: -6px;
  margin-right: -3px;
  width: 480px;
}

.tail-up {
 -moz-border-image: url(chrome://testpilot-os/skin/notification-tail-up.png) 26 56 22 18 / 26px 56px 22px 18px round stretch;
}

.tail-down {
 -moz-border-image: url(chrome://testpilot-os/skin/notification-tail-down.png) 26 56 22 18 / 26px 56px 22px 18px round stretch;
}


.pilot-notification-popup-container {
  -moz-appearance: none;
  margin-right: -42px;
  padding: 0px 5px 5px 5px;
  font-size: 14px;
}

.pilot-notification-toprow {
  margin-bottom: 12px;
}

#pilot-notification-text,
#pilot-notification-link {
  margin-bottom: 5px;
}

#pilot-notification-close {
  list-style-image: url("chrome://testpilot-os/skin/close_button.png");
  -moz-image-region: rect(0px, 14px, 14px, 0px);
  width: 14px;
  height: 14px;
}

#pilot-notification-close:hover {
  -moz-image-region: rect(0px, 28px, 14px, 14px);
}

#pilot-notification-close:hover:active {
  -moz-image-region: rect(0px, 42px, 14px, 28px);
}

.pilot-notify-me-when[disabled="true"] {
  color: -moz-dialogtext;
}
.pilot-title {
  font-size: 25px;
}

image.study-finished {
  list-style-image: url("chrome://testpilot/skin/tp-submit-48x48.png");
  height: 48px;
  width: 48px;
  margin-right: 8px;
}

image.study-submitted {
  list-style-image: url("chrome://testpilot/skin/status-completed.png");
  height: 32px;
  width: 64px;
  margin-right: 8px;
}

image.study-canceled {
  list-style-image: url("chrome://testpilot/skin/status-ejected.png");
  height: 32px;
  width: 64px;
  margin-right: 8px;
}

image.study-missed {
  list-style-image: url("chrome://testpilot/skin/status-missed.png");
  height: 32px;
  width: 64px;
  margin-right: 8px;
}

image.new-study {
  list-style-image: url("chrome://testpilot/skin/tp-study-48x48.png");
  height: 48px;
  width: 48px;
  margin-right: 8px;
}

image.new-results {
  list-style-image: url("chrome://testpilot/skin/tp-results-48x48.png");
  height: 48px;
  width: 48px;
  margin-right: 8px;
}

image.update-extension {
  list-style-image: url("chrome://testpilot/skin/testpilot_32x32.png");
  height: 48px;
  width: 48px;
  margin-right: 8px;
}

image.study-result {
  list-style-image: url("chrome://testpilot/skin/badge-default.png");
  height: 96px;
  width: 96px;
  margin-right: 8px;
}

/* All studies window */
.pilot-largetext {
  font-size: 16px;
}

#test-pilot-all-studies-window > .prefWindow-dlgbuttons {
    display: none;
}

.paneSelector {
    margin: 0 !important;
}

.paneSelector radio[pane="current-studies-pane-button"] .paneButtonIcon {
    list-style-image: url("chrome://testpilot/skin/tp-currentstudies-32x32.png");
    padding-top: 3px;
}
.paneSelector radio[pane="finished-studies-pane-button"] .paneButtonIcon {
    list-style-image: url("chrome://testpilot/skin/tp-completedstudies-32x32.png");
    padding-top: 3px;
}
.paneSelector radio[pane="study-results-pane-button"] .paneButtonIcon {
    list-style-image: url("chrome://testpilot/skin/tp-learned-32x32.png");
    padding-top: 3px;
}
.paneSelector radio[pane="settings-pane-button"] .paneButtonIcon {
    list-style-image: url("chrome://testpilot/skin/tp-settings-32x32.png");
    padding-top: 3px;
}

.pane-button-badge {
    background-color: green;
    color: white;
    font-weight: bold;
    padding: 2px;
    -moz-border-radius: 100%;
    margin-right: 25px;
    margin-bottom: 13px;
}

richlistbox.tp-study-list {
    overflow: auto;
    margin: 0px;
}

.tp-tab-panel {
    background-color: -moz-dialog;
    padding: 0px;
}

description.study-description {
    width: 350px;
}

description.study-title {
    width: 350px;
    font-size: 20px;
    text-align: left;
    margin-top: 10px;
}

richlistitem.tp-study-list {
    min-height: 120px;
    color: black;
    background-color: -moz-dialog;
}

richlistitem.tp-new-results {
    min-height: 120px;
    color: black;
    background-color: LemonChiffon;
}

richlistitem.tp-opted-out {
    min-height: 120px;
    color: grey;
    background-color: -moz-dialog;
}

vbox.results-thumbnail {
    height: 120px;
    width: 120px;
}

image.results-thumbnail {
    max-height: 90px;
    max-width:  90px;
    margin: 10px;
}

.notification-link {
    text-decoration: underline;
    cursor: pointer;
}

prefpane .groupbox-body {
  -moz-appearance: none;
  padding: 8px 4px 4px 4px;
}

prefpane .groupbox-title {
  background: url("chrome://global/skin/50pct_transparent_grey.png") repeat-x bottom left;
  margin-bottom: 4px;
}
